@@ -13,10 +13,10 @@ import (
 	"sync/atomic"
 	"time"
 
-	"github.com/canonical/go-dqlite/v2"
-	"github.com/canonical/go-dqlite/v2/client"
-	"github.com/canonical/go-dqlite/v2/driver"
-	"github.com/canonical/go-dqlite/v2/internal/protocol"
+	"github.com/canonical/go-dqlite/v3"
+	"github.com/canonical/go-dqlite/v3/client"
+	"github.com/canonical/go-dqlite/v3/driver"
+	"github.com/canonical/go-dqlite/v3/internal/protocol"
 	"github.com/pkg/errors"
 	"golang.org/x/sync/semaphore"
 )
@@ -195,8 +195,10 @@ func New(dir string, options ...Option) (app *App, err error) {
 		dqlite.WithFailureDomain(o.FailureDomain),
 		dqlite.WithNetworkLatency(o.NetworkLatency),
 		dqlite.WithSnapshotParams(o.SnapshotParams),
+		dqlite.WithBlockSize(o.BlockSize),
 		dqlite.WithDiskMode(o.DiskMode),
 		dqlite.WithAutoRecovery(o.AutoRecovery),
+		dqlite.WithBusyTimeout(o.BusyTimeout.Milliseconds()),
 	)
 	if err != nil {
 		stop()
