@@ -8,9 +8,9 @@ import (
 	"strings"
 	"time"
 
-	"github.com/canonical/go-dqlite/v2"
-	"github.com/canonical/go-dqlite/v2/client"
-	"github.com/canonical/go-dqlite/v2/internal/protocol"
+	"github.com/canonical/go-dqlite/v3"
+	"github.com/canonical/go-dqlite/v3/client"
+	"github.com/canonical/go-dqlite/v3/internal/protocol"
 )
 
 // Option can be used to tweak app parameters.
@@ -199,11 +199,16 @@ func WithSnapshotParams(params dqlite.SnapshotParams) Option {
 	}
 }
 
+// WithBlockSize sets the raft block size.
+func WithBlockSize(size uint) Option {
+	return func(options *options) {
+		options.BlockSize = size
+	}
+}
+
 // WithDiskMode enables or disables disk-mode.
-// WARNING: This is experimental API, use with caution
-// and prepare for data loss.
-// UNSTABLE: Behavior can change in future.
-// NOT RECOMMENDED for production use-cases, use at own risk.
+// DEPRECATED: this API will always fail on dqlite 1.18.3+ as support for
+// disk mode has been dropped.
 func WithDiskMode(disk bool) Option {
 	return func(options *options) {
 		options.DiskMode = disk
@@ -224,6 +229,20 @@ func WithAutoRecovery(recovery bool) Option {
 	}
 }
 
+// WithBusyTimeout sets the timeout for how long a database operation will
+// wait for a lock to be released before returning an error (SQLITE_BUSY),
+// that is the amount of time a writer will wait for others to finish writing
+// on the same database.
+//
+// Readers never wait writers nor readers.
+//
+// The default behavior is to fail immediately.
+func WithBusyTimeout(timeout time.Duration) Option {
+	return func(options *options) {
+		options.BusyTimeout = timeout
+	}
+}
+
 type tlsSetup struct {
 	Listen *tls.Config
 	Dial   *tls.Config
@@ -247,11 +266,13 @@ type options struct {
 	OnRolesAdjustment        func(client.NodeInfo, []client.NodeInfo) error
 	FailureDomain            uint64
 	NetworkLatency           time.Duration
+	BusyTimeout              time.Duration
 	ConcurrentLeaderConns    *int64
 	UnixSocket               string
 	SnapshotParams           dqlite.SnapshotParams
 	DiskMode                 bool
 	AutoRecovery             bool
+	BlockSize                uint
 }
 
 // Create a options object with sane defaults.
@@ -277,18 +298,18 @@ func isLoopback(iface *net.Interface) bool {
 // see https://stackoverflow.com/a/48519490/3613657
 // Valid IPv4 notations:
 //
-//    "192.168.0.1": basic
-//    "192.168.0.1:80": with port info
+//	"192.168.0.1": basic
+//	"192.168.0.1:80": with port info
 //
 // Valid IPv6 notations:
 //
-//    "::FFFF:C0A8:1": basic
-//    "::FFFF:C0A8:0001": leading zeros
-//    "0000:0000:0000:0000:0000:FFFF:C0A8:1": double colon expanded
-//    "::FFFF:C0A8:1%1": with zone info
-//    "::FFFF:192.168.0.1": IPv4 literal
-//    "[::FFFF:C0A8:1]:80": with port info
-//    "[::FFFF:C0A8:1%1]:80": with zone and port info
+//	"::FFFF:C0A8:1": basic
+//	"::FFFF:C0A8:0001": leading zeros
+//	"0000:0000:0000:0000:0000:FFFF:C0A8:1": double colon expanded
+//	"::FFFF:C0A8:1%1": with zone info
+//	"::FFFF:192.168.0.1": IPv4 literal
+//	"[::FFFF:C0A8:1]:80": with port info
+//	"[::FFFF:C0A8:1%1]:80": with zone and port info
 func isIpV4(ip string) bool {
 	return strings.Count(ip, ":") < 2
 }
