@@ -4,8 +4,8 @@ import (
 	"context"
 	"time"
 
-	"github.com/canonical/go-dqlite/v2/client"
-	"github.com/canonical/go-dqlite/v2/internal/bindings"
+	"github.com/canonical/go-dqlite/v3/client"
+	"github.com/canonical/go-dqlite/v3/internal/bindings"
 	"github.com/pkg/errors"
 )
 
@@ -22,13 +22,24 @@ type Node struct {
 // NodeInfo is a convenience alias for client.NodeInfo.
 type NodeInfo = client.NodeInfo
 
+type TrailingStrategy = bindings.TrailingStrategy
+
+const (
+	TrailingStrategyStatic  = bindings.TrailingStrategyStatic
+	TrailingStrategyDynamic = bindings.TrailingStrategyDynamic
+)
+
 // SnapshotParams exposes bindings.SnapshotParams. Used for setting dqlite's
 // snapshot parameters.
 // SnapshotParams.Threshold controls after how many raft log entries a snapshot is
 // taken. The higher this number, the lower the frequency of the snapshots.
 // SnapshotParams.Trailing controls how many raft log entries are retained after
 // taking a snapshot.
-type SnapshotParams = bindings.SnapshotParams
+type SnapshotParams struct {
+	Threshold uint64
+	Trailing  uint64
+	Strategy  TrailingStrategy
+}
 
 // Option can be used to tweak node parameters.
 type Option func(*options)
@@ -64,15 +75,24 @@ func WithFailureDomain(code uint64) Option {
 // WithSnapshotParams sets the snapshot parameters of the node.
 func WithSnapshotParams(params SnapshotParams) Option {
 	return func(options *options) {
-		options.SnapshotParams = params
+		options.SnapshotParams = bindings.SnapshotParams{
+			Threshold: params.Threshold,
+			Trailing:  params.Trailing,
+			Strategy:  params.Strategy,
+		}
+	}
+}
+
+// WithBlockSize sets the block size of the node.
+func WithBlockSize(size uint) Option {
+	return func(options *options) {
+		options.BlockSize = size
 	}
 }
 
 // WithDiskMode enables dqlite disk-mode on the node.
-// WARNING: This is experimental API, use with caution
-// and prepare for data loss.
-// UNSTABLE: Behavior can change in future.
-// NOT RECOMMENDED for production use-cases, use at own risk.
+// DEPRECATED: this API will always fail on dqlite 1.18.3+ as support for
+// disk mode has been dropped.
 func WithDiskMode(disk bool) Option {
 	return func(options *options) {
 		options.DiskMode = disk
@@ -93,6 +113,20 @@ func WithAutoRecovery(recovery bool) Option {
 	}
 }
 
+// WithBusyTimeout sets the timeout for how long a database operation will
+// wait for a lock to be released before returning an error (SQLITE_BUSY),
+// that is the amount of time a writer will wait for others to finish writing
+// on the same database.
+//
+// Readers never wait writers nor readers.
+//
+// The default behavior is to fail immediately.
+func WithBusyTimeout(msecs int64) Option {
+	return func(options *options) {
+		options.BusyTimeout = uint64(msecs)
+	}
+}
+
 // New creates a new Node instance.
 func New(id uint64, address string, dir string, options ...Option) (*Node, error) {
 	o := defaultOptions()
@@ -150,6 +184,18 @@ func New(id uint64, address string, dir string, options ...Option) (*Node, error
 			return nil, err
 		}
 	}
+	if o.BusyTimeout != 0 {
+		if err := server.SetBusyTimeout(o.BusyTimeout); err != nil {
+			cancel()
+			return nil, err
+		}
+	}
+	if o.BlockSize != 0 {
+		if err := server.SetBlockSize(o.BlockSize); err != nil {
+			cancel()
+			return nil, err
+		}
+	}
 
 	s := &Node{
 		server:      server,
@@ -187,10 +233,12 @@ type options struct {
 	DialFunc       client.DialFunc
 	BindAddress    string
 	NetworkLatency uint64
+	BusyTimeout    uint64
 	FailureDomain  uint64
 	SnapshotParams bindings.SnapshotParams
 	DiskMode       bool
 	AutoRecovery   bool
+	BlockSize      uint
 }
 
 // Close the server, releasing all resources it created.
@@ -237,18 +285,18 @@ func ReconfigureMembership(dir string, cluster []NodeInfo) error {
 // configuration is unsafe, and you should follow these steps to avoid data
 // loss and inconsistency:
 //
-// 1. Make sure no dqlite node in the cluster is running.
-// 2. Identify all dqlite nodes that have survived and that you want to be part
-//    of the recovered cluster. Call this the "new member list".
-// 3. Call ReadLastEntryInfo on each node in the member list, and find which
-//    node has the most recent entry according to LastEntryInfo.Before. Call this
-//    the "template node".
-// 4. Invoke ReconfigureMembershipExt exactly one time, on the template node.
-//    The arguments are the data directory of the template node and the new
-//    member list.
-// 5. Copy the data directory of the template node to all other nodes in the
-//    new member list, replacing their previous data directories.
-// 6. Restart all nodes in the new member list.
+//  1. Make sure no dqlite node in the cluster is running.
+//  2. Identify all dqlite nodes that have survived and that you want to be part
+//     of the recovered cluster. Call this the "new member list".
+//  3. Call ReadLastEntryInfo on each node in the member list, and find which
+//     node has the most recent entry according to LastEntryInfo.Before. Call this
+//     the "template node".
+//  4. Invoke ReconfigureMembershipExt exactly one time, on the template node.
+//     The arguments are the data directory of the template node and the new
+//     member list.
+//  5. Copy the data directory of the template node to all other nodes in the
+//     new member list, replacing their previous data directories.
+//  6. Restart all nodes in the new member list.
 func ReconfigureMembershipExt(dir string, cluster []NodeInfo) error {
 	server, err := bindings.NewNode(context.Background(), 1, "1", dir)
 	if err != nil {
@@ -303,8 +351,8 @@ func ReadLastEntryInfo(dir string) (LastEntryInfo, error) {
 // Create a options object with sane defaults.
 func defaultOptions() *options {
 	return &options{
-		DialFunc: client.DefaultDialFunc,
-		DiskMode: false, // Be explicit about not enabling disk-mode by default.
+		DialFunc:     client.DefaultDialFunc,
+		DiskMode:     false, // Be explicit about not enabling disk-mode by default.
 		AutoRecovery: true,
 	}
 }
